@@ -1,4 +1,4 @@
-from typing import TypeVar, Callable, Generic, Iterable
+from typing import TypeVar, Callable, Generic
 
 ValueType = TypeVar("ValueType")
 FunctionReturnType = TypeVar("FunctionReturnType")
@@ -8,6 +8,8 @@ class Pipe(Generic[ValueType]):
     def __init__(self, initial_value: ValueType) -> None:
         self._value: ValueType = initial_value
         self.p = self.pipe
+        self.c = self.check
+        self.u = self.unwrap
 
     def pipe(self, function: Callable[[ValueType], FunctionReturnType]):
         result: FunctionReturnType = function(self._value)
@@ -17,8 +19,11 @@ class Pipe(Generic[ValueType]):
         function(self._value)
         return Pipe(self._value)
 
-    def unpack(self):
+    def unwrap(self):
         return self._value
 
+    def __repr__(self) -> str:
+        return f"Pipe({self._value})"
+
 
 P = Pipe
